# coding: utf-8

"""
    FINBOURNE Workflow API

    FINBOURNE Technology  # noqa: E501

    Contact: info@finbourne.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, Dict
from pydantic.v1 import StrictStr, Field, BaseModel, Field, constr, validator 

class SleepResponse(BaseModel):
    """
    Configuration for a Worker that Sleeps for a user-defined amount of time  # noqa: E501
    """
    type:  StrictStr = Field(...,alias="type", description="The type of worker") 
    __properties = ["type"]

    @validator('type')
    def type_validate_enum(cls, value):
        """Validates the enum"""
        if value not in ('Sleep'):
            raise ValueError("must be one of enum values ('Sleep')")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def __str__(self):
        """For `print` and `pprint`"""
        return pprint.pformat(self.dict(by_alias=False))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> SleepResponse:
        """Create an instance of SleepResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> SleepResponse:
        """Create an instance of SleepResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return SleepResponse.parse_obj(obj)

        _obj = SleepResponse.parse_obj({
            "type": obj.get("type")
        })
        return _obj



# coding: utf-8

"""
    FINBOURNE Workflow API

    FINBOURNE Technology  # noqa: E501

    Contact: info@finbourne.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, Dict, Optional
from pydantic.v1 import StrictStr, Field, BaseModel, Field, constr, validator 

class TaskTransitionDefinition(BaseModel):
    """
    Defines a State change  # noqa: E501
    """
    from_state:  StrictStr = Field(...,alias="fromState", description="The State this Transition if coming From") 
    to_state:  StrictStr = Field(...,alias="toState", description="The State this Transition is going To") 
    trigger:  StrictStr = Field(...,alias="trigger", description="The Trigger for this Transition") 
    guard:  Optional[StrictStr] = Field(None,alias="guard", description="The Guard for this Transition, if any") 
    action:  Optional[StrictStr] = Field(None,alias="action", description="The Action to invoke on successful Transition") 
    __properties = ["fromState", "toState", "trigger", "guard", "action"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def __str__(self):
        """For `print` and `pprint`"""
        return pprint.pformat(self.dict(by_alias=False))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> TaskTransitionDefinition:
        """Create an instance of TaskTransitionDefinition from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if guard (nullable) is None
        # and __fields_set__ contains the field
        if self.guard is None and "guard" in self.__fields_set__:
            _dict['guard'] = None

        # set to None if action (nullable) is None
        # and __fields_set__ contains the field
        if self.action is None and "action" in self.__fields_set__:
            _dict['action'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> TaskTransitionDefinition:
        """Create an instance of TaskTransitionDefinition from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return TaskTransitionDefinition.parse_obj(obj)

        _obj = TaskTransitionDefinition.parse_obj({
            "from_state": obj.get("fromState"),
            "to_state": obj.get("toState"),
            "trigger": obj.get("trigger"),
            "guard": obj.get("guard"),
            "action": obj.get("action")
        })
        return _obj



# coding: utf-8

"""
    FINBOURNE Workflow API

    FINBOURNE Technology  # noqa: E501

    Contact: info@finbourne.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, Dict
from pydantic.v1 import StrictStr, Field, BaseModel, Field, StrictStr, constr 
from lusid_workflow.models.resource_id import ResourceId
from lusid_workflow.models.task_definition_version import TaskDefinitionVersion

class TaskSummary(BaseModel):
    """
    Summary of a Task created based on a Task Definition  # noqa: E501
    """
    id:  StrictStr = Field(...,alias="id", description="The unique id for this Task") 
    task_definition_id: ResourceId = Field(..., alias="taskDefinitionId")
    task_definition_version: TaskDefinitionVersion = Field(..., alias="taskDefinitionVersion")
    task_definition_display_name:  StrictStr = Field(...,alias="taskDefinitionDisplayName", description="The display name of the Task Definition used by this Task") 
    state:  StrictStr = Field(...,alias="state", description="Current State") 
    __properties = ["id", "taskDefinitionId", "taskDefinitionVersion", "taskDefinitionDisplayName", "state"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def __str__(self):
        """For `print` and `pprint`"""
        return pprint.pformat(self.dict(by_alias=False))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> TaskSummary:
        """Create an instance of TaskSummary from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of task_definition_id
        if self.task_definition_id:
            _dict['taskDefinitionId'] = self.task_definition_id.to_dict()
        # override the default output from pydantic by calling `to_dict()` of task_definition_version
        if self.task_definition_version:
            _dict['taskDefinitionVersion'] = self.task_definition_version.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> TaskSummary:
        """Create an instance of TaskSummary from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return TaskSummary.parse_obj(obj)

        _obj = TaskSummary.parse_obj({
            "id": obj.get("id"),
            "task_definition_id": ResourceId.from_dict(obj.get("taskDefinitionId")) if obj.get("taskDefinitionId") is not None else None,
            "task_definition_version": TaskDefinitionVersion.from_dict(obj.get("taskDefinitionVersion")) if obj.get("taskDefinitionVersion") is not None else None,
            "task_definition_display_name": obj.get("taskDefinitionDisplayName"),
            "state": obj.get("state")
        })
        return _obj



# coding: utf-8

"""
    FINBOURNE Workflow API

    FINBOURNE Technology  # noqa: E501

    Contact: info@finbourne.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, Dict, List, Optional
from pydantic.v1 import StrictStr, Field, BaseModel, Field, StrictStr, conlist, constr 
from lusid_workflow.models.link import Link
from lusid_workflow.models.parameter import Parameter
from lusid_workflow.models.resource_id import ResourceId
from lusid_workflow.models.result_field import ResultField
from lusid_workflow.models.version_info import VersionInfo
from lusid_workflow.models.worker_configuration_response import WorkerConfigurationResponse

class Worker(BaseModel):
    """
    Information about the Worker  # noqa: E501
    """
    id: ResourceId = Field(...)
    display_name:  StrictStr = Field(...,alias="displayName", description="Human readable name") 
    description:  Optional[StrictStr] = Field(None,alias="description", description="Human readable description") 
    worker_configuration: WorkerConfigurationResponse = Field(..., alias="workerConfiguration")
    version: Optional[VersionInfo] = None
    parameters: Optional[conlist(Parameter)] = Field(None, description="The Parameters this Worker accepts or requires.")
    result_fields: Optional[conlist(ResultField)] = Field(None, alias="resultFields", description="The Fields that the Worker results will come back with.")
    links: Optional[conlist(Link)] = None
    __properties = ["id", "displayName", "description", "workerConfiguration", "version", "parameters", "resultFields", "links"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def __str__(self):
        """For `print` and `pprint`"""
        return pprint.pformat(self.dict(by_alias=False))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Worker:
        """Create an instance of Worker from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of id
        if self.id:
            _dict['id'] = self.id.to_dict()
        # override the default output from pydantic by calling `to_dict()` of worker_configuration
        if self.worker_configuration:
            _dict['workerConfiguration'] = self.worker_configuration.to_dict()
        # override the default output from pydantic by calling `to_dict()` of version
        if self.version:
            _dict['version'] = self.version.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in parameters (list)
        _items = []
        if self.parameters:
            for _item in self.parameters:
                if _item:
                    _items.append(_item.to_dict())
            _dict['parameters'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in result_fields (list)
        _items = []
        if self.result_fields:
            for _item in self.result_fields:
                if _item:
                    _items.append(_item.to_dict())
            _dict['resultFields'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in links (list)
        _items = []
        if self.links:
            for _item in self.links:
                if _item:
                    _items.append(_item.to_dict())
            _dict['links'] = _items
        # set to None if description (nullable) is None
        # and __fields_set__ contains the field
        if self.description is None and "description" in self.__fields_set__:
            _dict['description'] = None

        # set to None if parameters (nullable) is None
        # and __fields_set__ contains the field
        if self.parameters is None and "parameters" in self.__fields_set__:
            _dict['parameters'] = None

        # set to None if result_fields (nullable) is None
        # and __fields_set__ contains the field
        if self.result_fields is None and "result_fields" in self.__fields_set__:
            _dict['resultFields'] = None

        # set to None if links (nullable) is None
        # and __fields_set__ contains the field
        if self.links is None and "links" in self.__fields_set__:
            _dict['links'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Worker:
        """Create an instance of Worker from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return Worker.parse_obj(obj)

        _obj = Worker.parse_obj({
            "id": ResourceId.from_dict(obj.get("id")) if obj.get("id") is not None else None,
            "display_name": obj.get("displayName"),
            "description": obj.get("description"),
            "worker_configuration": WorkerConfigurationResponse.from_dict(obj.get("workerConfiguration")) if obj.get("workerConfiguration") is not None else None,
            "version": VersionInfo.from_dict(obj.get("version")) if obj.get("version") is not None else None,
            "parameters": [Parameter.from_dict(_item) for _item in obj.get("parameters")] if obj.get("parameters") is not None else None,
            "result_fields": [ResultField.from_dict(_item) for _item in obj.get("resultFields")] if obj.get("resultFields") is not None else None,
            "links": [Link.from_dict(_item) for _item in obj.get("links")] if obj.get("links") is not None else None
        })
        return _obj



from typing import Optional

class ConfigurationOptions:
    
    def __init__(
        self, 
        total_timeout_ms: Optional[int] = None, 
        connect_timeout_ms: Optional[int] = None, 
        read_timeout_ms: Optional[int] = None, 
        rate_limit_retries: Optional[int] = None
    ):
        self.total_timeout_ms = total_timeout_ms
        self.connect_timeout_ms = connect_timeout_ms
        self.read_timeout_ms = read_timeout_ms
        self.rate_limit_retries = rate_limit_retries
        
    @property
    def total_timeout_ms(self):
        return self.__total_timeout_ms

    @total_timeout_ms.setter
    def total_timeout_ms(self, value):
        if value:
            if not isinstance(value, int):
                raise TypeError(f"total_timeout_ms must be type int but type '{type(value)}' used")
            if value < 0:
                raise ValueError(f"total_timeout_ms must be an integer greater than or equal to zero")
        self.__total_timeout_ms = value

    @property
    def connect_timeout_ms(self):
        return self.__connect_timeout_ms

    @connect_timeout_ms.setter
    def connect_timeout_ms(self, value):
        if value:
            if not isinstance(value, int):
                raise TypeError(f"connect_timeout_ms must be type int but type '{type(value)}' used")
            if value < 0:
                raise ValueError(f"connect_timeout_ms must be an integer greater than or equal to zero")
        self.__connect_timeout_ms = value

    @property
    def read_timeout_ms(self):
        return self.__read_timeout_ms

    @read_timeout_ms.setter
    def read_timeout_ms(self, value):
        if value:
            if not isinstance(value, int):
                raise TypeError(f"read_timeout_ms must be type int but type '{type(value)}' used")
            if value < 0:
                raise ValueError(f"read_timeout_ms must be an integer greater than or equal to zero")
        self.__read_timeout_ms = value

    @property
    def rate_limit_retries(self):
        return self.__rate_limit_retries

    @rate_limit_retries.setter
    def rate_limit_retries(self, value):
        if value:
            if not isinstance(value, int):
                raise TypeError(f"rate_limit_retries must be type int but type '{type(value)}' used")
            if value < 0:
                raise ValueError(f"rate_limit_retries must be an integer greater than or equal to zero")
        self.__rate_limit_retries = value


# coding: utf-8

"""
    FINBOURNE Workflow API

    FINBOURNE Technology  # noqa: E501

    Contact: info@finbourne.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Any, Dict, Optional
from pydantic.v1 import StrictStr, Field, BaseModel, Field, StrictStr, constr 
from lusid_workflow.models.event_handler_mapping import EventHandlerMapping
from lusid_workflow.models.event_matching_pattern import EventMatchingPattern
from lusid_workflow.models.resource_id import ResourceId
from lusid_workflow.models.task_activity import TaskActivity

class CreateEventHandlerRequest(BaseModel):
    """
    Contains information for creating an Event Handler  # noqa: E501
    """
    id: ResourceId = Field(...)
    display_name:  StrictStr = Field(...,alias="displayName", description="Human readable name") 
    description:  Optional[StrictStr] = Field(None,alias="description", description="Human readable description") 
    status:  StrictStr = Field(...,alias="status", description="The current status of the event handler") 
    event_matching_pattern: EventMatchingPattern = Field(..., alias="eventMatchingPattern")
    run_as_user_id: EventHandlerMapping = Field(..., alias="runAsUserId")
    task_definition_id: ResourceId = Field(..., alias="taskDefinitionId")
    task_definition_as_at: Optional[datetime] = Field(None, alias="taskDefinitionAsAt", description="AsAt of the required task definition")
    task_activity: TaskActivity = Field(..., alias="taskActivity")
    __properties = ["id", "displayName", "description", "status", "eventMatchingPattern", "runAsUserId", "taskDefinitionId", "taskDefinitionAsAt", "taskActivity"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def __str__(self):
        """For `print` and `pprint`"""
        return pprint.pformat(self.dict(by_alias=False))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CreateEventHandlerRequest:
        """Create an instance of CreateEventHandlerRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of id
        if self.id:
            _dict['id'] = self.id.to_dict()
        # override the default output from pydantic by calling `to_dict()` of event_matching_pattern
        if self.event_matching_pattern:
            _dict['eventMatchingPattern'] = self.event_matching_pattern.to_dict()
        # override the default output from pydantic by calling `to_dict()` of run_as_user_id
        if self.run_as_user_id:
            _dict['runAsUserId'] = self.run_as_user_id.to_dict()
        # override the default output from pydantic by calling `to_dict()` of task_definition_id
        if self.task_definition_id:
            _dict['taskDefinitionId'] = self.task_definition_id.to_dict()
        # override the default output from pydantic by calling `to_dict()` of task_activity
        if self.task_activity:
            _dict['taskActivity'] = self.task_activity.to_dict()
        # set to None if description (nullable) is None
        # and __fields_set__ contains the field
        if self.description is None and "description" in self.__fields_set__:
            _dict['description'] = None

        # set to None if task_definition_as_at (nullable) is None
        # and __fields_set__ contains the field
        if self.task_definition_as_at is None and "task_definition_as_at" in self.__fields_set__:
            _dict['taskDefinitionAsAt'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CreateEventHandlerRequest:
        """Create an instance of CreateEventHandlerRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return CreateEventHandlerRequest.parse_obj(obj)

        _obj = CreateEventHandlerRequest.parse_obj({
            "id": ResourceId.from_dict(obj.get("id")) if obj.get("id") is not None else None,
            "display_name": obj.get("displayName"),
            "description": obj.get("description"),
            "status": obj.get("status"),
            "event_matching_pattern": EventMatchingPattern.from_dict(obj.get("eventMatchingPattern")) if obj.get("eventMatchingPattern") is not None else None,
            "run_as_user_id": EventHandlerMapping.from_dict(obj.get("runAsUserId")) if obj.get("runAsUserId") is not None else None,
            "task_definition_id": ResourceId.from_dict(obj.get("taskDefinitionId")) if obj.get("taskDefinitionId") is not None else None,
            "task_definition_as_at": obj.get("taskDefinitionAsAt"),
            "task_activity": TaskActivity.from_dict(obj.get("taskActivity")) if obj.get("taskActivity") is not None else None
        })
        return _obj



# coding: utf-8

"""
    FINBOURNE Workflow API

    FINBOURNE Technology  # noqa: E501

    Contact: info@finbourne.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Any, Dict, Optional
from pydantic.v1 import StrictStr, Field, BaseModel, Field, StrictStr, constr, validator 
from lusid_workflow.models.field_mapping import FieldMapping
from lusid_workflow.models.resource_id import ResourceId
from lusid_workflow.models.result_matching_pattern import ResultMatchingPattern

class ResultantChildTaskConfiguration(BaseModel):
    """
    Child Task Configuration  # noqa: E501
    """
    result_matching_pattern: Optional[ResultMatchingPattern] = Field(None, alias="resultMatchingPattern")
    task_definition_id: ResourceId = Field(..., alias="taskDefinitionId")
    task_definition_as_at: Optional[datetime] = Field(None, alias="taskDefinitionAsAt", description="TaskDefinition AsAt timestamp")
    initial_trigger:  Optional[StrictStr] = Field(None,alias="initialTrigger", description="The Initial Trigger for automatic start") 
    child_task_fields: Dict[str, FieldMapping] = Field(..., alias="childTaskFields", description="Field Mappings")
    map_stacking_key_from:  Optional[StrictStr] = Field(None,alias="mapStackingKeyFrom", description="The field to be mapped as the ChildTasks Stacking Key") 
    __properties = ["resultMatchingPattern", "taskDefinitionId", "taskDefinitionAsAt", "initialTrigger", "childTaskFields", "mapStackingKeyFrom"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def __str__(self):
        """For `print` and `pprint`"""
        return pprint.pformat(self.dict(by_alias=False))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ResultantChildTaskConfiguration:
        """Create an instance of ResultantChildTaskConfiguration from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of result_matching_pattern
        if self.result_matching_pattern:
            _dict['resultMatchingPattern'] = self.result_matching_pattern.to_dict()
        # override the default output from pydantic by calling `to_dict()` of task_definition_id
        if self.task_definition_id:
            _dict['taskDefinitionId'] = self.task_definition_id.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each value in child_task_fields (dict)
        _field_dict = {}
        if self.child_task_fields:
            for _key in self.child_task_fields:
                if self.child_task_fields[_key]:
                    _field_dict[_key] = self.child_task_fields[_key].to_dict()
            _dict['childTaskFields'] = _field_dict
        # set to None if task_definition_as_at (nullable) is None
        # and __fields_set__ contains the field
        if self.task_definition_as_at is None and "task_definition_as_at" in self.__fields_set__:
            _dict['taskDefinitionAsAt'] = None

        # set to None if initial_trigger (nullable) is None
        # and __fields_set__ contains the field
        if self.initial_trigger is None and "initial_trigger" in self.__fields_set__:
            _dict['initialTrigger'] = None

        # set to None if map_stacking_key_from (nullable) is None
        # and __fields_set__ contains the field
        if self.map_stacking_key_from is None and "map_stacking_key_from" in self.__fields_set__:
            _dict['mapStackingKeyFrom'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ResultantChildTaskConfiguration:
        """Create an instance of ResultantChildTaskConfiguration from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ResultantChildTaskConfiguration.parse_obj(obj)

        _obj = ResultantChildTaskConfiguration.parse_obj({
            "result_matching_pattern": ResultMatchingPattern.from_dict(obj.get("resultMatchingPattern")) if obj.get("resultMatchingPattern") is not None else None,
            "task_definition_id": ResourceId.from_dict(obj.get("taskDefinitionId")) if obj.get("taskDefinitionId") is not None else None,
            "task_definition_as_at": obj.get("taskDefinitionAsAt"),
            "initial_trigger": obj.get("initialTrigger"),
            "child_task_fields": dict(
                (_k, FieldMapping.from_dict(_v))
                for _k, _v in obj.get("childTaskFields").items()
            )
            if obj.get("childTaskFields") is not None
            else None,
            "map_stacking_key_from": obj.get("mapStackingKeyFrom")
        })
        return _obj
